CREATE TABLE "user" (
  user_id       INTEGER NOT NULL PRIMARY KEY,
  user_name     varchar(50) NOT NULL,
  token         varchar(255),
  avatar        varchar(500),
  slogan        varchar(255),
  last_login_at integer(10));

CREATE TABLE user_config (
  k             varchar(50) NOT NULL PRIMARY KEY,
  v             text,
  updated_at    timestamp,
  synced_at     timestamp);

CREATE TABLE user_book (
  _id              INTEGER PRIMARY KEY AUTOINCREMENT,
  bk_id            integer(10) NOT NULL,
  level_star       integer(10) NOT NULL,
  star             integer(10) NOT NULL,
  started_at       timestamp,
  finished_at      timestamp,
  last_recited_at  timestamp,
  real_last_recited_at timestamp,
  recited_word_num integer(10),
  recited_unit_num integer(10),
  favorite         boolean,
  plan_type         integer(10),
  default_plan_num  integer(10),
  today_recited_unit integer(10),
  subscribed       integer(1) DEFAULT '1' NOT NULL,
  finished         integer(1) DEFAULT '0' NOT NULL);

CREATE TABLE user_book_word (
  word_item_id     INTEGER(10) NOT NULL PRIMARY KEY,
  bk_id            integer(10) NOT NULL,
  unit_id          integer(10) NOT NULL,
  word_id          integer(10) NOT NULL,
  word             varchar(100) NOT NULL,
  right_times      integer(10) NOT NULL,
  wrong_times      integer(10) NOT NULL,
  finished         integer(1) DEFAULT '0' NOT NULL,
  is_right_last    integer(1) DEFAULT '1' NOT NULL,
  is_grasp         integer(1) DEFAULT "1" NOT NULL,
  last_recited_at  timestamp,
  mark            tinyint(3),
  marked_at       timestamp,
  synced_at       timestamp);

CREATE TABLE user_book_unit (
  _id               INTEGER PRIMARY KEY AUTOINCREMENT,
  bk_id             integer(10) NOT NULL,
  unit_id           integer(10) NOT NULL,
  star              integer(10) NOT NULL,
  finished          integer(10) NOT NULL,
  finished_at       timestamp,
  last_recited_at   timestamp);

CREATE TABLE user_finished_word_log (
  _id         INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  bk_id       integer(10) NOT NULL,
  unit_id     integer(10) NOT NULL,
  word_id     integer(10) NOT NULL,
  word        varchar(100) NOT NULL,
  finished_at integer(10) NOT NULL);

CREATE TABLE user_reciting_log (
  _id              INTEGER NOT NULL PRIMARY KEY,
  bk_id            integer(10) NOT NULL,
  unit_id          integer(10) NOT NULL,
  recited_num      integer(10),
  recited_duration integer(10),
  created_at       timestamp NOT NULL);

CREATE TABLE user_book_unit_log (
  _id        INTEGER NOT NULL PRIMARY KEY,
  bk_id      integer(10) NOT NULL,
  unit_id    integer(10) NOT NULL,
  star       integer(10) NOT NULL,
  source     integer(2) NOT NULL,
  finished   integer(1) NOT NULL,
  created_at timestamp NOT NULL);

CREATE TABLE user_pk_result (
  pk_id     INTEGER NOT NULL PRIMARY KEY,
  pk_result TEXT);

CREATE TABLE review_recited_date (
  _id           INTEGER PRIMARY KEY AUTOINCREMENT,
  bk_id        integer(10) NOT NULL,
  rec_start_at timestamp,
  rec_end_at   timestamp,
  created_at   timestamp);

CREATE TABLE review_recited_unit (
  _id           INTEGER PRIMARY KEY AUTOINCREMENT,
  rec_date_id     integer(10) NOT NULL,
  bk_id           integer(10) NOT NULL,
  unit_id         integer(10) NOT NULL,
  unit_index      integer(10),
  word_size       integer(10),
  bk_res_version  integer(10),
  last_recited_at timestamp,
  synced_at       timestamp);

CREATE TABLE review_recited_word (
  word_item_id  INTEGER NOT NULL PRIMARY KEY,
  rec_unit_id  integer(10) NOT NULL,
  bk_id           integer(10) NOT NULL,
  unit_id         integer(10) NOT NULL,
  is_right     boolean,
  invalid      boolean DEFAULT '0',
  period_index integer(10) DEFAULT '-1',
  created_at   timestamp NOT NULL,
  updated_at   timestamp);

CREATE TABLE review_recited_unit_period (
  _id           INTEGER PRIMARY KEY AUTOINCREMENT,
  rec_unit_id  integer(10) NOT NULL,
  chk_point_id integer(10) NOT NULL,
  bk_id        integer(10) NOT NULL,
  period_index integer(3),
  appear_at    timestamp,
  finished     boolean DEFAULT '0',
  created_at   timestamp,
  updated_at   timestamp);

CREATE TABLE review_check_point (
  _id           INTEGER PRIMARY KEY AUTOINCREMENT,
  bk_id            integer(10) NOT NULL,
  type             integer(1),
  pre_unit_index   integer(10),
  appear_at        timestamp,
  word_size        integer(10),
  last_reviewed_at integer(10),
  enabled          boolean DEFAULT '1',
  finished         integer(10),
  created_at       timestamp,
  updated_at       timestamp);

CREATE TABLE review_recited_word_check_point_ref (
  _id INTEGER PRIMARY KEY AUTOINCREMENT,
  bk_id        integer(10) NOT NULL,
  word_item_id integer(10) NOT NULL,
  chk_point_id integer(10) NOT NULL,
  period_index integer(3));

CREATE TABLE IF NOT EXISTS user_lock_screen_word (
  _id                   INTEGER PRIMARY KEY AUTOINCREMENT,
  word_item_id          INTEGER(10) NOT NULL,
  bk_id                 INTEGER(10) NOT NULL,
  unit_id               INTEGER(10) NOT NULL,
  raw_word_id           INTEGER(10) NOT NULL,
  source                INTEGER     NOT NULL,
  is_grasp              INTEGER(1) DEFAULT "1" NOT NULL,
  show_times            INTEGER(10) NOT NULL DEFAULT 0);

-- 现有情况下，只建立词书计划相关的任务(这张表就已经足以表达现有计划的需求)
CREATE TABLE IF NOT EXISTS book_task (
  _id                   INTEGER PRIMARY KEY AUTOINCREMENT,
  bk_id                 integer(10) NOT NULL,
  goal                  integer(10),
  modify_times          integer(10),
  order_idx             integer(10),
  plan_type             integer(10),
  last_finished_time    timestamp,
  created_at            timestamp,
  updated_at            timestamp
  );

CREATE INDEX idx_user_config_1 on user_config(k);

CREATE INDEX idx_user_book_1 on user_book(bk_id);

CREATE INDEX idx_user_book_unit_1 on user_book_unit(bk_id,unit_id);
CREATE INDEX idx_user_book_unit_2 on user_book_unit(star);
CREATE INDEX idx_user_book_unit_3 on user_book_unit(finished,last_recited_at);

CREATE INDEX idx_user_book_unit_log_1 on user_book_unit_log(bk_id);

CREATE INDEX idx_review_recited_date_1 on review_recited_date(bk_id,rec_start_at,rec_end_at);

CREATE INDEX idx_review_recited_unit_1 on review_recited_unit(bk_id,unit_id);
CREATE INDEX idx_review_recited_unit_2 on review_recited_unit(rec_date_id,synced_at);

CREATE INDEX idx_review_recited_word_1 on review_recited_word(rec_unit_id);
CREATE INDEX idx_review_recited_word_2 on review_recited_word(bk_id,unit_id);
CREATE INDEX idx_review_recited_word_3 on review_recited_word(invalid,period_index);

CREATE INDEX idx_review_recited_unit_period_1 on review_recited_unit_period(bk_id,chk_point_id);
CREATE INDEX idx_review_recited_unit_period_2 on review_recited_unit_period(rec_unit_id);

CREATE INDEX idx_review_check_point_1 on review_check_point(bk_id,enabled,type);
CREATE INDEX idx_review_check_point_2 on review_check_point(appear_at);
CREATE INDEX idx_review_check_point_3 on review_check_point(pre_unit_index);
CREATE INDEX idx_review_check_point_4 on review_check_point(word_size);
CREATE INDEX idx_review_check_point_5 on review_check_point(finished);

CREATE INDEX idx_review_recited_word_check_point_ref_1 on review_recited_word_check_point_ref(word_item_id,chk_point_id);
